@@ -1,4 +1,9 @@
 
+from .excel_address import col_letter_offset
+from .excel_address import col_letter
+from .excel_address import col_number
+
+from .workbook import get_opened_workbook
 from .workbook import open_workbook
 from .workbook import close_workbook
 from .workbook import new_excel_application
@@ -6,19 +11,18 @@ from .workbook import any_excel_application
 from .workbook import empty_excel_application
 from .workbook import all_excel_instances
 
-from .excel_address import col_letter_offset
-from .excel_address import col_letter
-from .excel_address import col_number
-
 from .classes import excel_levity_cls
 
-__all__ = ['open_workbook',
+__all__ = ['col_letter_offset',
+           'col_letter',
+           'col_number',
+
+           'get_opened_workbook',
+           'open_workbook',
            'close_workbook',
            'new_excel_application',
            'any_excel_application',
            'empty_excel_application',
            'all_excel_instances',
-           'col_letter_offset',
-           'col_letter',
-           'col_number',
+
            'excel_levity_cls']
